@@ -1,4 +1,5 @@
 package Dist::Zilla::Plugin::PerlTidy;
+our $VERSION = '0.06';
 
 # ABSTRACT: PerlTidy in Dist::Zilla
 
@@ -61,10 +62,16 @@ no Moose;
 1;
 __END__
 
+
+
 =head1 NAME
 
 Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
 
+=head1 VERSION
+
+version 0.06
+
 =head1 SYNOPSIS
 
     # dist.ini
@@ -74,6 +81,21 @@ Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
     [PerlTidy]
     perltidyrc = xt/.perltidyrc
 
+=head1 AUTHOR
+
+  Fayland Lam <fayland@gmail.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2009 by Fayland Lam.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as perl itself.
+
+=head1 NAME
+
+Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
+
 =head1 perltidyrc
 
 =head2 dist.ini
@@ -105,3 +127,6 @@ Copyright 2009, Fayland Lam.
 
 This program is free software; you may redistribute it and/or modify it under
 the same terms as Perl itself.
+
+
+__END__
